pub enum ArrayVecError {
CapacityOverflow,
}Expand description
Errors that can occur when operating on an ArrayVec.
Variants
CapacityOverflow
The operation would exceed the fixed capacity of the ArrayVec.